@@ -1,5 +1,5 @@
 package Math::Shape::Point;
-$Math::Shape::Point::VERSION = '0.09';
+$Math::Shape::Point::VERSION = '1.00';
 use strict;
 use warnings;
 use Math::Trig ':pi';
@@ -51,6 +51,27 @@ sub advance {
 }
 
 
+sub retreat {
+    $_[0]->{x} -= int(sin($_[0]->{r}) * $_[1]);
+    $_[0]->{y} -= int(cos($_[0]->{r}) * $_[1]);
+    1;
+}
+
+
+sub move_left {
+    $_[0]->{x} += int(sin( $_[0]->{r} - pip2 ) * $_[1]);
+    $_[0]->{y} += int(cos( $_[0]->{r} - pip2 ) * $_[1]);
+    1;
+}
+
+
+sub move_right {
+    $_[0]->{x} += int(sin( $_[0]->{r} + pip2 ) * $_[1]);
+    $_[0]->{y} += int(cos( $_[0]->{r} + pip2 ) * $_[1]);
+    1;
+}
+
+
 sub rotate {
     $_[0]->{r} = $_[0]->{r} + $_[0]->normalize_radian($_[1]);
     1;
@@ -126,7 +147,7 @@ Math::Shape::Point - a 2d point object in cartesian space with utility angle met
 
 =head1 VERSION
 
-version 0.09
+version 1.00
 
 =head1 SYNOPSIS
 
@@ -184,6 +205,24 @@ Requires a numeric distance argument - moves the point forward that distance in
 
     $p->advance(5);
 
+=head2 retreat
+
+Requires a numeric distance argument - moves the point backwards that distance in Cartesian coordinates from the direction it is facing.
+
+    $p->retreat(5);
+
+=head2 move_left
+
+Requires a numeric distance argument - moves the point that distance to the left.
+
+    $p->move_left(3);
+
+=head2 move_right
+
+Requires a numeric distance argument - moves the point that distance to the right.
+
+    $p->move_right(7);
+
 =head2 rotate
 
 Updates the point's facing direction by radians.
